16.85. cdist-type__link(7) — cdist 6.5.4 documentation

# 16.85. cdist-type__link(7)

## 16.85.1. NAME

cdist-type__link - Manage links (hard and symbolic)

## 16.85.2. DESCRIPTION

This cdist type allows you to manage hard and symbolic links. The given object id is the destination for the link.

## 16.85.3. REQUIRED PARAMETERS

source
  Specifies the link source.
type
  Specifies the link type: Either hard or symoblic.

## 16.85.4. OPTIONAL PARAMETERS

state
  'present' or 'absent', defaults to 'present'

## 16.85.5. MESSAGES

created <destination>
  Link to destination was created.
removed <destination>
  Link to destination was removed.
removed <destination> (directory)
  Destination was removed because state is `present` and destination was directory.
removed <destination> (wrongsource)
  Destination was removed because state is `present` and destination link source was wrong.

## 16.85.6. EXAMPLES

    # Create hard link of /etc/shadow
    __link /root/shadow --source /etc/shadow --type hard

    # Relative symbolic link
    __link /etc/apache2/sites-enabled/www.test.ch   \
       --source ../sites-available/www.test.ch      \
       --type symbolic

    # Absolute symbolic link
    __link /opt/plone --source /home/services/plone --type symbolic

    # Remove link
    __link /opt/plone --state absent

## 16.85.7. AUTHORS

Nico Schottelius <nico-cdist--@--schottelius.org>

## 16.85.8. COPYING

Copyright (C) 2011-2012 Nico Schottelius. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.